:notoc:

======
Coiled
======

👋 Welcome to Coiled!

`Coiled <https://coiled.io/>`_ helps you easily create and manage
`Dask <https://dask.org/>`_ deployments to natively scale Python.


.. toctree::
   :maxdepth: 1
   :hidden:

   user_guide/index
